summaryrefslogtreecommitdiff
path: root/src/mainboard/supermicro/h8scm
diff options
context:
space:
mode:
authorMartin Roth <martin.roth@se-eng.com>2015-01-04 15:22:26 -0700
committerMartin Roth <gaumless@gmail.com>2015-01-06 06:34:18 +0100
commit6355cbff51966144d5b709a73e24622df3e96122 (patch)
tree7c542ed72d0a93e5317b1555b76a8afa172ca939 /src/mainboard/supermicro/h8scm
parentd30746ab6bf2f5237e9a9f5b68719f9651060027 (diff)
downloadcoreboot-6355cbff51966144d5b709a73e24622df3e96122.tar.xz
AMD platforms: fix callout_entry doxygen errors
Somewhere along the line, the sb_cfg parameter name was changed to config, but this wasn't carried into the documentation or the function prototypes everywhere. Change-Id: Iccb0829c2f50370dddb70af915a6759316c4727a Signed-off-by: Martin Roth <martin.roth@se-eng.com> Reviewed-on: http://review.coreboot.org/8098 Reviewed-by: Edward O'Callaghan <eocallaghan@alterapraxis.com> Tested-by: build bot (Jenkins)
Diffstat (limited to 'src/mainboard/supermicro/h8scm')
-rw-r--r--src/mainboard/supermicro/h8scm/sb700_cfg.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/mainboard/supermicro/h8scm/sb700_cfg.h b/src/mainboard/supermicro/h8scm/sb700_cfg.h
index 40c89fa59f..2f3ece2b15 100644
--- a/src/mainboard/supermicro/h8scm/sb700_cfg.h
+++ b/src/mainboard/supermicro/h8scm/sb700_cfg.h
@@ -233,9 +233,9 @@ void sb700_cimx_config(AMDSBCFG *sb_cfg);
*
* @param[in] func Southbridge CIMx Function ID.
* @param[in] data Southbridge Input Data.
* @param[in] sb_cfg Southbridge configuration structure pointer.
*
*/
-u32 sb700_callout_entry(u32 func, u32 data, void* sb_cfg);
+u32 sb700_callout_entry(u32 func, u32 data, void* config);
#endif //_SB700_CFG_H_
@@ -233,9 +233,9 @@ void sb700_cimx_config(AMDSBCFG *sb_cfg);
* @param[in] func Southbridge CIMx Function ID.
* @param[in] data Southbridge Input Data.
- * @param[in] sb_cfg Southbridge configuration structure pointer.
+ * @param[in] config Southbridge configuration structure pointer.
*
*/